[KSplash Theme: MoodinKDE]
Name = MoodinKDE
Description = Fading splash screen based on the svg wallpaper (Lineart Logo)
Version = 1.2
Author = Christian Leh <moodwrod@web.de>
Homepage = http://moodwrod.com
Engine = Moodin

BeginOpacity = 0.1
BaseResolution = 1280,1024

UseIconSet = true
IconSetSize = 64

Image1 = kcmsystem
Image2 = kcontrol
Image3 = kcmpci
Image7 = kmenuedit

LineUpImages = true

Labels = 1
Label1 = Welcome
LabelFont1 = Trebuchet MS,48,-1,0,0,0
LabelCoords1 = -1,400

StatusCoords = -1,450

ImageOffset1 = 0,20
