[KSplash Theme: FingerPrint]
Name = FingerPrint
Description = Taste your fingers (wallpaper from Dalmases http://www.deviantart.com/deviation/11180503/)
Version = 1.2
Author = Christian Leh <moodwrod@web.de>
Homepage = http://moodwrod.com
Engine = Moodin

BeginOpacity = 0.1
BaseResolution = 1280,1024

UseIconSet = false

ImageCoords1 = 682,285
ImageCoords2 = 682,138
ImageCoords3 = 805,239
ImageCoords4 = 805,94
ImageCoords5 = 928,314
ImageCoords6 = 925,170
ImageCoords7 = 1122,472
ImageCoords8 = 249,418

StatusMessage1 = # 0.5
StatusMessage2 = # 1.0
StatusMessage3 = # 1.5
StatusMessage4 = # 2.0
StatusMessage5 = # 2.5
StatusMessage6 = # 3.0
StatusMessage7 = # 3.5
StatusMessage8 = Access Granted

Labels = 2
Label1 = Validating...
LabelFont1 = Trebuchet MS,24,-1,5,50,0
LabelCoords1 = 75,75

Label2 = ML:USER:loginname
LabelFont2 = Trebuchet MS,16,-1,5,50,0
LabelCoords2 = 250,255

StatusCoords = 100,100
